pub struct Topic(pub String);Available on crate feature
router only.Expand description
An extractor for the topic portion of a Message
Tuple Fields
0: StringTrait Implementations
Sourceimpl<S> FromRequest<S> for Topic
Extracts the Message::topic from a Request and wraps it in a Topic.
impl<S> FromRequest<S> for Topic
Extracts the Message::topic from a Request and wraps it in a Topic.
fn from_request(request: &Request<S>) -> RouterResult<Self>